module TopModule (
    input logic CLOCK_50,        // Тактовый сигнал 50 МГц
    input logic [9:0] SW,        // Переключатели для входных данных
    input logic [0:0] KEY,       // Кнопка сброса
    input wire UART_RXD,         // Вход UART RX
    output wire UART_TXD,        // Выход UART TX
    output logic [6:0] HEX0,     // Дисплей 1 (Младший разряд)
    output logic [6:0] HEX1,     // Дисплей 2
    output logic [6:0] HEX2,     // Дисплей 3
    output logic [6:0] HEX3,     // Дисплей 4
    output logic [6:0] HEX4,     // Дисплей 5
    output logic [6:0] HEX5      // Дисплей 6 (Старший разряд)
);

    // Входные данные
    logic [31:0] in1, in2, in3, in4;
    assign in1 = {24'b0, SW[9:8], SW[7:6], SW[5:4]};
    assign in2 = {24'b0, SW[3:2], SW[1:0], 2'b00};
    assign in3 = {24'b0, SW[9:6]};
    assign in4 = {24'b0, SW[5:2]};

    // Выходные данные
    logic [31:0] out1, out2, out3;

    // Экземпляр нейронной сети
    NeuralNetwork nn (
        .clk(CLOCK_50),
        .reset(~KEY[0]),
        .in1(in1),
        .in2(in2),
        .in3(in3),
        .in4(in4),
        .out1(out1),
        .out2(out2),
        .out3(out3)
    );



    // Преобразование результатов в HEX-дисплей
    HexDisplay hex0(.value(out1[3:0]), .hex_out(HEX0));
    HexDisplay hex1(.value(out1[7:4]), .hex_out(HEX1));
    HexDisplay hex2(.value(out2[3:0]), .hex_out(HEX2));
    HexDisplay hex3(.value(out2[7:4]), .hex_out(HEX3));
    HexDisplay hex4(.value(out3[3:0]), .hex_out(HEX4));
    HexDisplay hex5(.value(out3[7:4]), .hex_out(HEX5));

endmodule
