module UART_Receiver (
    input wire clk,       // Системный тактовый сигнал
    input wire rx,        // UART RX (подключается к TX Arduino)
    output reg [31:0] data_out, // Выходные данные
    output reg valid      // Флаг, что данные получены
);

    reg [7:0] uart_buffer [0:4];  // Буфер для хранения 5 байтов (старт + 4 байта данных)
    integer index = 0;
    reg [3:0] state = 0;
    reg [7:0] rx_shift = 0;
    reg [3:0] bit_count = 0;
    reg rx_ready = 0;
    reg [7:0] rx_data;

    always @(posedge clk) begin
        if (rx_ready) begin
            uart_buffer[index] <= rx_data;
            index <= index + 1;

            if (index == 4) begin
                if (uart_buffer[0] == 8'hAA) begin  // Проверяем стартовый байт
                    data_out <= {uart_buffer[1], uart_buffer[2], uart_buffer[3], uart_buffer[4]};
                    valid <= 1;
                end
                index <= 0;
            end
        end else begin
            valid <= 0;
        end
    end

    // Простая обработка UART данных (примерная логика)
    always @(posedge clk) begin
        if (rx == 0 && bit_count == 0) begin
            bit_count <= 10;  // Начинаем принимать 8 бит + старт/стоп
            rx_shift <= 0;
        end else if (bit_count > 0) begin
            rx_shift <= {rx, rx_shift[7:1]};
            bit_count <= bit_count - 1;
            if (bit_count == 1) begin
                rx_ready <= 1;
                rx_data <= rx_shift;
            end else begin
                rx_ready <= 0;
            end
        end
    end

endmodule
